@@ -27,6 +27,13 @@ module OpenID
       attr_accessor :ns_alias, :mode, :ns_uri
 
       NS_URI = 'http://openid.net/srv/ax/1.0'
+
+      begin
+        Message.register_namespace_alias(NS_URI, 'ax')
+      rescue NamespaceAliasRegistrationError => e
+        Util.log(e)
+      end
+
       def initialize
         @ns_alias = 'ax'
         @ns_uri = NS_URI
@@ -38,7 +45,7 @@ module OpenID
       # Raise an exception if the mode in the attribute exchange
       # arguments does not match what is expected for this class.
       def check_mode(ax_args)
-        actual_mode = ax_args['mode']
+        actual_mode = ax_args ? ax_args['mode'] : nil
         if actual_mode != @mode
           raise Error, "Expected mode #{mode.inspect}, got #{actual_mode.inspect}"
         end
@@ -110,7 +117,7 @@ module OpenID
     class FetchRequest < AXMessage
       attr_reader :requested_attributes
       attr_accessor :update_url
-      
+
       MODE = 'fetch_request'
 
       def initialize(update_url = nil)
@@ -137,7 +144,7 @@ module OpenID
         aliases = NamespaceMap.new
         required = []
         if_available = []
-        ax_args = new_args 
+        ax_args = new_args
         @requested_attributes.each{|type_uri, attribute|
           if attribute.ns_alias
             name = aliases.add_alias(type_uri, attribute.ns_alias)
@@ -268,8 +275,7 @@ module OpenID
       def initialize
         super()
         @mode = nil
-        @data = {}
-        @data.default = []
+        @data = Hash.new { |hash, key| hash[key] = [] }
       end
 
       # Add a single value for the given attribute type to the
@@ -296,12 +302,21 @@ module OpenID
         @data.each{|type_uri, values|
           name = aliases.add(type_uri)
           ax_args['type.'+name] = type_uri
-          ax_args['count.'+name] = values.size.to_s
+          if values.size > 1
+            ax_args['count.'+name] = values.size.to_s
 
-          values.each_with_index{|value, i|
-            key = "value.#{name}.#{i+1}"
-            ax_args[key] = value
-          }
+            values.each_with_index{|value, i|
+              key = "value.#{name}.#{i+1}"
+              ax_args[key] = value
+            }
+            # for attributes with only a single value, use a
+            # nice shortcut to only show the value w/o the count
+          else 
+            values.each do |value|
+              key = "value.#{name}"
+              ax_args[key] = value
+            end
+          end
         }
         return ax_args
       end
@@ -328,7 +343,7 @@ module OpenID
           if count_s.nil?
             value = ax_args['value.'+name]
             if value.nil?
-              raise IndexError, "Missing #{'value.'+name} in FetchResponse" 
+              raise IndexError, "Missing #{'value.'+name} in FetchResponse"
             elsif value.empty?
               values = []
             else
@@ -365,7 +380,7 @@ module OpenID
       def get(type_uri)
         @data[type_uri]
       end
-      
+
       # retrieve the list of values for this attribute
       def [](type_uri)
         @data[type_uri]
@@ -381,11 +396,17 @@ module OpenID
     # A fetch_response attribute exchange message
     class FetchResponse < KeyValueMessage
       attr_reader :update_url
+      # Use the aliases variable to manually add alias names in the response.
+      # They'll be returned to the client in the format: 
+      #   openid.ax.type.email=http://openid.net/schema/contact/internet/email
+      #   openid.ax.value.email=guy@example.com
+      attr_accessor :aliases
 
       def initialize(update_url = nil)
         super()
         @mode = 'fetch_response'
         @update_url = update_url
+        @aliases = NamespaceMap.new
       end
 
       # Serialize this object into arguments in the attribute
@@ -394,7 +415,6 @@ module OpenID
       # validated against this request, and empty responses for requested
       # fields with no data will be sent.
       def get_extension_args(request = nil)
-        aliases = NamespaceMap.new
         zero_value_types = []
 
         if request
@@ -412,28 +432,29 @@ module OpenID
             # Copy the aliases from the request so that reading
             # the response in light of the request is easier
             if attr_info.ns_alias.nil?
-              aliases.add(attr_info.type_uri)
+              @aliases.add(attr_info.type_uri)
             else
-              aliases.add_alias(attr_info.type_uri, attr_info.ns_alias)
+              @aliases.add_alias(attr_info.type_uri, attr_info.ns_alias)
             end
             values = @data[attr_info.type_uri]
             if values.empty? # @data defaults to []
               zero_value_types << attr_info
             end
+
             if attr_info.count != UNLIMITED_VALUES and attr_info.count < values.size
               raise Error, "More than the number of requested values were specified for #{attr_info.type_uri.inspect}"
             end
           }
         end
 
-        kv_args = _get_extension_kv_args(aliases)
+        kv_args = _get_extension_kv_args(@aliases)
 
         # Add the KV args into the response with the args that are
         # unique to the fetch_response
         ax_args = new_args
 
         zero_value_types.each{|attr_info|
-          name = aliases.get_alias(attr_info.type_uri)
+          name = @aliases.get_alias(attr_info.type_uri)
           kv_args['type.' + name] = attr_info.type_uri
           kv_args['count.' + name] = '0'
         }
@@ -461,7 +482,7 @@ module OpenID
         begin
           obj.parse_extension_args(ax_args)
           return obj
-        rescue Error => e
+        rescue Error
           return nil
         end
       end
@@ -469,26 +490,26 @@ module OpenID
 
     # A store request attribute exchange message representation
     class StoreRequest < KeyValueMessage
-      
+
       MODE = 'store_request'
-      
+
       def initialize
         super
         @mode = MODE
       end
-      
+
       # Extract a StoreRequest from an OpenID message
       # message: OpenID::Message
       # return a StoreRequest or nil if AX arguments are not present
       def self.from_openid_request(oidreq)
-        message = oidreq.message 
+        message = oidreq.message
         ax_args = message.get_args(NS_URI)
         return nil if ax_args.empty? or ax_args['mode'] != MODE
         req = new
         req.parse_extension_args(ax_args)
         req
       end
-      
+
       def get_extension_args(aliases=nil)
         ax_args = new_args
         kv_args = _get_extension_kv_args(aliases)
@@ -516,13 +537,13 @@ module OpenID
         end
         @error_message = error_message
       end
-      
+
       def self.from_success_response(success_response)
         resp = nil
         ax_args = success_response.message.get_args(NS_URI)
         resp = ax_args.key?('error') ? new(false, ax_args['error']) : new
       end
-      
+
       def succeeded?
         @mode == SUCCESS_MODE
       end
