@@ -1,3 +1,7 @@
+require 'test/unit'
+require 'testutil'
+require 'util'
+require 'uri'
 require 'openid/server'
 require 'openid/cryptutil'
 require 'openid/association'
@@ -6,11 +10,6 @@ require 'openid/message'
 require 'openid/store/memory'
 require 'openid/dh'
 require 'openid/consumer/associationmanager'
-require 'util'
-require "testutil"
-
-require 'test/unit'
-require 'uri'
 
 # In general, if you edit or add tests here, try to move in the
 # direction of testing smaller units.  For testing the external
@@ -57,7 +56,7 @@ module OpenID
         'openid.error' => 'plucky',
       }
 
-      rt_base, result_args = e.encode_to_url.split('?', 2)
+      _, result_args = e.encode_to_url.split('?', 2)
       result_args = Util.parse_query(result_args)
       assert_equal(result_args, expected_args)
     end
@@ -81,7 +80,7 @@ module OpenID
         'openid.error' => 'plucky',
       }
 
-      rt_base, result_args = e.encode_to_url.split('?', 2)
+      _, result_args = e.encode_to_url.split('?', 2)
       result_args = Util.parse_query(result_args)
       assert_equal(result_args, expected_args)
     end
@@ -99,12 +98,6 @@ module OpenID
                                     })
       e = Server::ProtocolError.new(args, "plucky")
       assert(e.has_return_to)
-      expected_args = {
-        'openid.ns' => OPENID2_NS,
-        'openid.mode' => 'error',
-        'openid.error' => 'plucky',
-      }
-
       assert(e.which_encoding == Server::ENCODE_HTML_FORM)
       assert(e.to_form_markup == e.to_message.to_form_markup(
                                                              args.get_arg(OPENID_NS, 'return_to')))
@@ -128,7 +121,7 @@ module OpenID
 
       assert(e.which_encoding == Server::ENCODE_URL)
 
-      rt_base, result_args = e.encode_to_url.split('?', 2)
+      _, result_args = e.encode_to_url.split('?', 2)
       result_args = Util.parse_query(result_args)
       assert_equal(result_args, expected_args)
     end
@@ -208,7 +201,7 @@ module OpenID
       begin
         result = @decode.call(args)
       rescue ArgumentError => err
-        assert(!err.to_s.index('values').nil?, err)
+        assert !err.to_s.index('values').nil?
       else
         flunk("Expected ArgumentError, but got result #{result}")
       end
@@ -662,7 +655,7 @@ module OpenID
       args = {'openid.ns' => 'Vegetables',
               'openid.mode' => 'associate'}
       begin
-        r = @decode.call(args)
+        @decode.call(args)
       rescue Server::ProtocolError => err
         assert(err.openid_message)
         assert(err.to_s.index('Vegetables'))
@@ -1008,7 +1001,7 @@ module OpenID
       assert(webresponse.headers.has_key?('location'))
       location = webresponse.headers['location']
       query = Util.parse_query(URI::parse(location).query)
-      assert(!query.has_key?('openid.sig'), response.fields.to_post_args())
+      assert !query.has_key?('openid.sig')
     end
 
     def test_assocReply
@@ -1205,9 +1198,8 @@ module OpenID
 
     def test_answerAllowWithNoIdentity
       @request.identity = IDENTIFIER_SELECT
-      selected_id = 'http://anon.unittest/9861'
       assert_raise(ArgumentError) {
-        answer = @request.answer(true, nil, nil)
+        @request.answer(true, nil, nil)
       }
     end
 
@@ -1234,7 +1226,7 @@ module OpenID
       @request.op_endpoint = nil
 
       assert_raise(ArgumentError) {
-        resp = @request.answer(false)
+        @request.answer(false)
       }
     end
 
@@ -1250,7 +1242,7 @@ module OpenID
       url = @request.encode_to_url(server_url)
       assert(url.starts_with?(server_url))
 
-      unused, query = url.split("?", 2)
+      _, query = url.split("?", 2)
       args = Util.parse_query(query)
 
       m = Message.from_post_args(args)
@@ -1448,7 +1440,7 @@ module OpenID
       result = @request.encode_to_url(server_url)
 
       # How to check?  How about a round-trip test.
-      base, result_args = result.split('?', 2)
+      _, result_args = result.split('?', 2)
       result_args = Util.parse_query(result_args)
       message = Message.from_post_args(result_args)
       rebuilt_request = Server::CheckIDRequest.from_message(message,
@@ -1530,7 +1522,7 @@ module OpenID
                    {'blue' => 'star',
                      'mode' => 'id_res',
                    })
-      
+
       assert_equal(@response.fields.get_args(namespace),
                    {'bright' => 'potato'})
     end
@@ -1613,7 +1605,7 @@ module OpenID
       r = @request.answer(@signatory)
       assert_equal({'is_valid' => 'false'},
                    r.fields.get_args(OPENID_NS))
-      
+
     end
 
     def test_replay
@@ -1750,7 +1742,7 @@ module OpenID
                            invalid_s1,
                            invalid_s1_2,
                           ]
-            
+
       bad_request_argss.each { |request_args|
         message = Message.from_post_args(request_args)
         assert_raise(Server::ProtocolError) {
@@ -1920,16 +1912,6 @@ module OpenID
     end
   end
 
-  class Counter
-    def initialize
-      @count = 0
-    end
-
-    def inc
-      @count += 1
-    end
-  end
-
   class UnhandledError < Exception
   end
 
@@ -1947,7 +1929,7 @@ module OpenID
       request.mode = "monkeymode"
       request.message = Message.new(OPENID1_NS)
       assert_raise(RuntimeError) {
-        webresult = @server.handle_request(request)
+        @server.handle_request(request)
       }
     end
 
@@ -1962,8 +1944,6 @@ module OpenID
     end
 
     def test_dispatch
-      monkeycalled = Counter.new()
-
       @server.extend(InstanceDefExtension)
       @server.instance_def(:openid_monkeymode) do |request|
         raise UnhandledError
@@ -1973,7 +1953,7 @@ module OpenID
       request.mode = "monkeymode"
       request.message = Message.new(OPENID1_NS)
       assert_raise(UnhandledError) {
-        webresult = @server.handle_request(request)
+        @server.handle_request(request)
       }
     end
 
@@ -2061,7 +2041,7 @@ module OpenID
                                        'session_type' => 'no-encryption',
                                      })
 
-        req = Server::AssociateRequest.from_message(m)
+        Server::AssociateRequest.from_message(m)
       }
     end
 
@@ -2299,8 +2279,7 @@ module OpenID
         verified = @signatory.verify(assoc_handle, signed)
       }
 
-      assert(!verified)
-      #assert(@messages)
+      assert !verified
     end
 
     def test_verifyAssocMismatch
@@ -2322,16 +2301,14 @@ module OpenID
         verified = @signatory.verify(assoc_handle, signed)
       }
 
-      assert(!verified)
-      #assert(@messages)
+      assert !verified
     end
 
     def test_getAssoc
       assoc_handle = makeAssoc(true)
       assoc = @signatory.get_association(assoc_handle, true)
-      assert(assoc)
-      assert_equal(assoc.handle, assoc_handle)
-      # @failIf(@messages, @messages)
+      assert assoc
+      assert_equal assoc.handle, assoc_handle
     end
 
     def test_getAssocExpired
@@ -2340,8 +2317,7 @@ module OpenID
       silence_logging {
         assoc = @signatory.get_association(assoc_handle, true)
       }
-      assert(!assoc, assoc)
-      # assert(@messages)
+      assert !assoc
     end
 
     def test_getAssocInvalid
@@ -2428,7 +2404,7 @@ module OpenID
                     'openid.assoc_type' => 'HMAC-SHA1'}
       areq = @server.decode_request(assoc_args)
       aresp = @server.handle_request(areq)
-      
+
       amess = aresp.fields
       assert(amess.is_openid1)
       ahandle = amess.get_arg(OPENID_NS, 'assoc_handle')
@@ -2441,7 +2417,7 @@ module OpenID
                       'openid.return_to' => 'http://example.com/openid/consumer',
                       'openid.assoc_handle' => ahandle,
                       'openid.identity' => 'http://foo.com/'}
-      
+
       cireq = @server.decode_request(checkid_args)
       ciresp = cireq.answer(true)
 
@@ -2449,7 +2425,7 @@ module OpenID
 
       assert_equal(assoc.get_message_signature(signed_resp.fields),
                    signed_resp.fields.get_arg(OPENID_NS, 'sig'))
-                   
+
       assert(assoc.check_message_signature(signed_resp.fields))
     end
 
